@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: apc_app.c,v 1.120 2008/04/24 15:15:10 dk Exp $
+ * $Id$
  */
 
 /***********************************************************/
@@ -1074,13 +1074,6 @@ apc_application_unlock( Handle self)
    return true;
 }
 
-static XBool
-any_event( Display *d, XEvent *ev, XPointer arg)
-{
-   (void)d; (void)ev; (void)arg; (void)any_event;
-   return true;
-}
-
 Bool
 apc_application_sync(void)
 {
